@@ -10,7 +10,7 @@
    This file is part of LibVEX, a library for dynamic binary
    instrumentation and translation.
 
-   Copyright (C) 2004-2007 OpenWorks LLP.  All rights reserved.
+   Copyright (C) 2004-2008 OpenWorks LLP.  All rights reserved.
 
    This library is made available under a dual licensing scheme.
 
@@ -110,8 +110,8 @@ extern const HChar* LibVEX_ppVexHwCaps  ( VexArch, UInt );
 
 
 /* This struct is a bit of a hack, but is needed to carry misc
-   important bits of info about an arch.  Fields which are optional or
-   ignored on some arch should be set to zero. */
+   important bits of info about an arch.  Fields which are meaningless
+   or ignored for the platform in question should be set to zero. */
 
 typedef
    struct {
@@ -127,6 +127,110 @@ extern
 void LibVEX_default_VexArchInfo ( /*OUT*/VexArchInfo* vai );
 
 
+/* This struct carries guest and host ABI variant information that may
+   be needed.  Fields which are meaningless or ignored for the
+   platform in question should be set to zero.
+
+   Settings which are believed to be correct are:
+
+   guest_stack_redzone_size
+      guest is ppc32-linux                ==> 0
+      guest is ppc64-linux                ==> 288
+      guest is ppc32-aix5                 ==> 220
+      guest is ppc64-aix5                 ==> unknown
+      guest is amd64-linux                ==> 128
+      guest is other                      ==> inapplicable
+
+   guest_amd64_assume_fs_is_zero
+      guest is amd64-linux                ==> True
+      guest is amd64-darwin               ==> False
+      guest is other                      ==> inapplicable
+
+   guest_amd64_assume_gs_is_0x60
+      guest is amd64-darwin               ==> True
+      guest is amd64-linux                ==> False
+      guest is other                      ==> inapplicable
+
+   guest_ppc_zap_RZ_at_blr
+      guest is ppc64-linux                ==> True
+      guest is ppc32-linux                ==> False
+      guest is ppc64-aix5                 ==> unknown
+      guest is ppc32-aix5                 ==> False
+      guest is other                      ==> inapplicable
+
+   guest_ppc_zap_RZ_at_bl
+      guest is ppc64-linux                ==> const True
+      guest is ppc32-linux                ==> const False
+      guest is ppc64-aix5                 ==> unknown
+      guest is ppc32-aix5                 ==> True except for calls to
+                                              millicode, $SAVEFn, $RESTFn
+      guest is other                      ==> inapplicable
+
+   guest_ppc_sc_continues_at_LR:
+      guest is ppc32-aix5  or ppc64-aix5  ==> True
+      guest is ppc32-linux or ppc64-linux ==> False
+      guest is other                      ==> inapplicable
+
+   host_ppc_calls_use_fndescrs:
+      host is ppc32-linux                 ==> False
+      host is ppc64-linux                 ==> True
+      host is ppc32-aix5 or ppc64-aix5    ==> True
+      host is other                       ==> inapplicable
+
+   host_ppc32_regalign_int64_args:
+      host is ppc32-linux                 ==> True
+      host is ppc32-aix5                  ==> False
+      host is other                       ==> inapplicable
+*/
+
+typedef
+   struct {
+      /* PPC and AMD64 GUESTS only: how many bytes below the 
+         stack pointer are validly addressible? */
+      Int guest_stack_redzone_size;
+
+      /* AMD64 GUESTS only: should we translate %fs-prefixed
+         instructions using the assumption that %fs always contains
+         zero? */
+      Bool guest_amd64_assume_fs_is_zero;
+
+      /* AMD64 GUESTS only: should we translate %gs-prefixed
+         instructions using the assumption that %gs always contains
+         0x60? */
+      Bool guest_amd64_assume_gs_is_0x60;
+
+      /* PPC GUESTS only: should we zap the stack red zone at a 'blr'
+         (function return) ? */
+      Bool guest_ppc_zap_RZ_at_blr;
+
+      /* PPC GUESTS only: should we zap the stack red zone at a 'bl'
+         (function call) ?  Is supplied with the guest address of the
+         target of the call since that may be significant.  If NULL,
+         is assumed equivalent to a fn which always returns False. */
+      Bool (*guest_ppc_zap_RZ_at_bl)(Addr64);
+
+      /* PPC32/PPC64 GUESTS only: where does the kernel resume after
+         'sc'?  False => Linux style, at the next insn.  True => AIX
+         style, at the address stated in the link register. */
+      Bool guest_ppc_sc_continues_at_LR;
+
+      /* PPC32/PPC64 HOSTS only: does '&f' give us a pointer to a
+         function descriptor on the host, or to the function code
+         itself?  True => descriptor, False => code. */
+      Bool host_ppc_calls_use_fndescrs;
+
+      /* PPC32 HOSTS only: when generating code to pass a 64-bit value
+         (actual parameter) in a pair of regs, should we skip an arg
+         reg if it is even-numbered?  True => yes, False => no. */
+      Bool host_ppc32_regalign_int64_args;
+   }
+   VexAbiInfo;
+
+/* Write default settings info *vbi. */
+extern 
+void LibVEX_default_VexAbiInfo ( /*OUT*/VexAbiInfo* vbi );
+
+
 /*-------------------------------------------------------*/
 /*--- Control of Vex's optimiser (iropt).             ---*/
 /*-------------------------------------------------------*/
@@ -235,6 +339,9 @@ typedef
       /* Whereabouts is the stack pointer? */
       Int offset_SP;
       Int sizeof_SP; /* 4 or 8 */
+      /* Whereabouts is the frame pointer? */
+      Int offset_FP;
+      Int sizeof_FP; /* 4 or 8 */
       /* Whereabouts is the instruction pointer? */
       Int offset_IP;
       Int sizeof_IP; /* 4 or 8 */
@@ -251,14 +358,18 @@ typedef
 /* A note about guest state layout.
 
    LibVEX defines the layout for the guest state, in the file
-   pub/libvex_guest_<arch>.h.  The struct will have an 8-aligned size.
-   Each translated bb is assumed to be entered with a specified
-   register pointing at such a struct.  Beyond that is a shadow
-   state area with the same size as the struct.  Beyond that is
-   a spill area that LibVEX may spill into.  It must have size
+   pub/libvex_guest_<arch>.h.  The struct will have an 16-aligned
+   size.  Each translated bb is assumed to be entered with a specified
+   register pointing at such a struct.  Beyond that is two copies of
+   the shadow state area with the same size as the struct.  Beyond
+   that is a spill area that LibVEX may spill into.  It must have size
    LibVEX_N_SPILL_BYTES, and this must be a 16-aligned number.
 
-   On entry, the baseblock pointer register must be 8-aligned.
+   On entry, the baseblock pointer register must be 16-aligned.
+
+   There must be no holes in between the primary guest state, its two
+   copies, and the spill area.  In short, all 4 areas must have a
+   16-aligned size and be 16-aligned, and placed back-to-back.
 */
 
 #define LibVEX_N_SPILL_BYTES 2048
@@ -320,11 +431,13 @@ typedef
    many of them, it seems better to have a structure. */
 typedef
    struct {
-      /* IN: The instruction sets we are translating from and to. */
+      /* IN: The instruction sets we are translating from and to.  And
+         guest/host misc info. */
       VexArch      arch_guest;
       VexArchInfo  archinfo_guest;
       VexArch      arch_host;
       VexArchInfo  archinfo_host;
+      VexAbiInfo   abiinfo_both;
 
       /* IN: an opaque value which is passed as the first arg to all
          callback functions supplied in this struct.  Vex has no idea
@@ -355,30 +468,32 @@ typedef
 
       /* IN: optionally, two instrumentation functions.  May be
 	 NULL. */
-      IRBB*   (*instrument1) ( /*callback_opaque*/void*, 
-                               IRBB*, 
+      IRSB*   (*instrument1) ( /*callback_opaque*/void*, 
+                               IRSB*, 
                                VexGuestLayout*, 
                                VexGuestExtents*,
                                IRType gWordTy, IRType hWordTy );
-      IRBB*   (*instrument2) ( /*callback_opaque*/void*, 
-                               IRBB*, 
+      IRSB*   (*instrument2) ( /*callback_opaque*/void*, 
+                               IRSB*, 
                                VexGuestLayout*, 
                                VexGuestExtents*,
                                IRType gWordTy, IRType hWordTy );
 
+      IRSB* (*finaltidy) ( IRSB* );
+
       /* IN: should this translation be self-checking?  default: False */
       Bool    do_self_check;
 
       /* IN: optionally, a callback which allows the caller to add its
          own IR preamble following the self-check and any other
          VEX-generated preamble, if any.  May be NULL.  If non-NULL,
-         the IRBB under construction is handed to this function, which
+         the IRSB under construction is handed to this function, which
          presumably adds IR statements to it.  The callback may
          optionally complete the block and direct bb_to_IR not to
          disassemble any instructions into it; this is indicated by
          the callback returning True.
       */
-      Bool    (*preamble_function)(/*callback_opaque*/void*, IRBB*);
+      Bool    (*preamble_function)(/*callback_opaque*/void*, IRSB*);
 
       /* IN: debug: trace vex activity at various points */
       Int     traceflags;
